/************************************************************************************************

 Author        : ADI - Apps            www.analog.com/AduC7060

 Date          : November 2007

 File          : Timer0_IRQ.c

 Hardware      : ADuC706x

 Description   : The program shows how to configure P1.6 as an output and to toggle the LED on the 
 				Evaluation board.
 				By pressing the INT0 button (XIRQ0), the toggle rate of the LED connected
				to P1.6 will change. The toggle rate of the LED is controlled by Timer 1
*************************************************************************************************/
// Bit Definitions
#define BIT0  0x01
#define BIT1  0x02
#define BIT2  0x04
#define BIT3  0x08
#define BIT4  0x10
#define BIT5  0x20
#define BIT6  0x40
#define BIT7  0x80
#define BIT8  0x100
#define BIT9  0x200
#define BIT10 0x400
#define BIT11 0x800
#define BIT12 0x1000
#define BIT13 0x2000
#define BIT14 0x4000
#define BIT15 0x8000
#define BIT16 0x10000
#define BIT21 0x200000
#define BIT22 0x400000
#define BIT24 0x1000000
#define BIT26 0x4000000
#define BIT30 0x40000000

unsigned char ucToggleRate = 0;
unsigned int uiTest = 0;

#include<aduc7060.h>

int main(void)
{
	POWKEY1 = 0x1;
	POWCON0 = 0x78;		   // Set core to max CPU speed of 10.24Mhz
	POWKEY2 = 0xF4;

	GP1DAT  = BIT30;		// Configure P1.6 as an output 
	uiTest = GP0CON0;
	uiTest = GP0CON1;
//	GP0DAT = BIT16 + BIT24;
	GP0SET = BIT16; 

	// Initilize Timer 1 in Periodic mode with timeout period of 1 Second
	T1LD  = 0x2000;			// 32768 clock ticks
	T1CON = BIT6 + BIT7;	// Periodic mode, enable timer, 32768hz clock/1
	IRQCONE = BIT1;			// Rising edge
	IRQEN = BIT4 + BIT13;			// Enable Timer 1 IRQ

	while(1)
	{

	}
}

void IRQ_Handler(void) __irq  
{
   unsigned long IRQSTATUS = 0;

	IRQSTATUS = IRQSTA;	   // Read off IRQSTA register

	if ((IRQSTATUS & BIT4) == BIT4)	//Timer 1 interrupt source
	{
		 GP1DAT ^= BIT22;	// Toggle LED on Evaluation board (P1.6)
		 T1CLRI = 0x55;		// Clear the currently active Timer0 Irq

	}
	if ((IRQSTATUS & BIT13) == BIT13)	//External Interrupt0 source
	{
		 ucToggleRate++;
		 IRQCLRE = BIT13;			   // Clear External Interrupt 0

		 if (ucToggleRate == 4)
		 	ucToggleRate = 0;
		 switch (ucToggleRate)
		 {
		  	case 0:
			{
				T1LD  = 0x8000;	// 1 second toggle rate
			 	break;
			}
			case 1:
			{
				T1LD  = 0x4000;	// 1/2 second toggle rate
			 	break;
			}
			case 2:
			{
				T1LD  = 0x2000;	// 1/4 second toggle rate
			 	break;
			}
			case 3:
			{
				T1LD  = 0x10000;	// 2 second toggle rate
			 	break;
			}
		 } 
	}
}


